==> intel-compute-runtime_25.31.34666.3.orig.tar.gz: compute-runtime-25.31.34666.3/opencl/test/unit_test/offline_compiler/mock/mock_ocloc_fcl_facade.h <==
/*
 * Copyright (C) 2022-2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once

#include "shared/offline_compiler/source/ocloc_fcl_facade.h"

#include <optional>
#include <string>

class OclocArgHelper;

namespace NEO {

class MockOclocFclFacade : public OclocFclFacade {
  public:
    using OclocFclFacade::fclDeviceCtx;

    bool shouldFailLoadingOfFclLib{false};
    bool shouldFailLoadingOfFclCreateMainFunction{false};
    bool shouldFailCreationOfFclMain{false};
    bool shouldFailCreationOfFclDeviceContext{false};
    bool shouldReturnInvalidFclPlatformHandle{false};
    std::optional<bool> isFclInterfaceCompatibleReturnValue{};
    std::optional<std::string> getIncompatibleInterfaceReturnValue{};
    std::optional<bool> shouldPopulateFclInterfaceReturnValue{};
    int populateFclInterfaceCalledCount{0};

    MockOclocFclFacade(OclocArgHelper *argHelper);
    ~MockOclocFclFacade() override;

    std::unique_ptr<OsLibrary> loadFclLibrary() const override;
    CIF::CreateCIFMainFunc_t loadCreateFclMainFunction() const override;

    CIF::RAII::UPtr_t<CIF::CIFMain> createFclMain(CIF::CreateCIFMainFunc_t createMainFunction) const override;

    bool isFclInterfaceCompatible() const override;

    std::string getIncompatibleInterface() const override;

    CIF::RAII::UPtr_t<IGC::FclOclDeviceCtxTagOCL> createFclDeviceContext() const override;

    bool shouldPopulateFclInterface() const override;

    CIF::RAII::UPtr_t<IGC::PlatformTagOCL> getPlatformHandle() const override;

    void populateFclInterface(IGC::PlatformTagOCL &handle, const HardwareInfo &hwInfo) override;
};

} // namespace NEO

==> intel-compute-runtime-26.05.37020.3.tar.gz: compute-runtime-26.05.37020.3/opencl/test/unit_test/offline_compiler/mock/mock_ocloc_fcl_facade.h <==
/*
 * Copyright (C) 2022-2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once

#include "shared/offline_compiler/source/ocloc_fcl_facade.h"

#include <optional>
#include <string>

class OclocArgHelper;

namespace NEO {

class MockOclocFclFacade : public OclocFclFacade {
  public:
    using OclocFclFacade::fclDeviceCtx;

    bool shouldFailLoadingOfFclLib{false};
    bool shouldFailLoadingOfFclCreateMainFunction{false};
    bool shouldFailCreationOfFclMain{false};
    bool shouldFailCreationOfFclDeviceContext{false};
    bool shouldReturnInvalidFclPlatformHandle{false};
    std::optional<bool> isFclInterfaceCompatibleReturnValue{};
    std::optional<std::string> getIncompatibleInterfaceReturnValue{};
    std::optional<bool> shouldPopulateFclInterfaceReturnValue{};
    int populateFclInterfaceCalledCount{0};

    MockOclocFclFacade(OclocArgHelper *argHelper);
    ~MockOclocFclFacade() override;

    std::unique_ptr<OsLibrary> loadFclLibrary() const override;
    CIF::CreateCIFMainFunc_t loadCreateFclMainFunction() const override;

    CIF::RAII::UPtr_t<CIF::CIFMain> createFclMain(CIF::CreateCIFMainFunc_t createMainFunction) const override;

    bool isFclInterfaceCompatible() const override;

    std::string getIncompatibleInterface() const override;

    CIF::RAII::UPtr_t<NEO::FclOclDeviceCtxTag> createFclDeviceContext() const override;

    bool shouldPopulateFclInterface() const override;

    CIF::RAII::UPtr_t<NEO::PlatformTag> getPlatformHandle() const override;

    void populateFclInterface(NEO::PlatformTag &handle, const HardwareInfo &hwInfo) override;
};

} // namespace NEO
